@@ -16,72 +16,58 @@ package tsdb
 import (
 	"context"
 	"fmt"
-	"os"
 	"path/filepath"
 
-	"github.com/go-kit/kit/log"
-	"github.com/prometheus/prometheus/pkg/labels"
+	"github.com/go-kit/log"
+
+	"github.com/prometheus/prometheus/storage"
 )
 
 var ErrInvalidTimes = fmt.Errorf("max time is lesser than min time")
 
-type MetricSample struct {
-	TimestampMs int64
-	Value       float64
-	Labels      labels.Labels
-}
-
-// CreateHead creates a TSDB writer head to write the sample data to.
-func CreateHead(samples []*MetricSample, chunkRange int64, chunkDir string, logger log.Logger) (*Head, error) {
-	head, err := NewHead(nil, logger, nil, chunkRange, chunkDir, nil, DefaultStripeSize, nil)
-
-	if err != nil {
-		return nil, err
-	}
-	app := head.Appender(context.TODO())
-	for _, sample := range samples {
-		_, err = app.Add(sample.Labels, sample.TimestampMs, sample.Value)
-		if err != nil {
-			return nil, err
-		}
-	}
-	err = app.Commit()
-	if err != nil {
-		return nil, err
-	}
-	return head, nil
-}
-
 // CreateBlock creates a chunkrange block from the samples passed to it, and writes it to disk.
-func CreateBlock(samples []*MetricSample, dir string, mint, maxt int64, logger log.Logger) (string, error) {
-	chunkRange := maxt - mint
+func CreateBlock(series []storage.Series, dir string, chunkRange int64, logger log.Logger) (string, error) {
 	if chunkRange == 0 {
 		chunkRange = DefaultBlockDuration
 	}
 	if chunkRange < 0 {
 		return "", ErrInvalidTimes
 	}
-	chunkDir := filepath.Join(dir, "chunks_tmp")
+
+	w, err := NewBlockWriter(logger, dir, chunkRange)
+	if err != nil {
+		return "", err
+	}
 	defer func() {
-		os.RemoveAll(chunkDir)
+		if err := w.Close(); err != nil {
+			logger.Log("err closing blockwriter", err.Error())
+		}
 	}()
-	head, err := CreateHead(samples, chunkRange, chunkDir, logger)
-	if err != nil {
-		return "", err
-	}
-	defer head.Close()
 
-	compactor, err := NewLeveledCompactor(context.Background(), nil, logger, ExponentialBlockRanges(DefaultBlockDuration, 3, 5), nil)
-	if err != nil {
+	ctx := context.Background()
+	app := w.Appender(ctx)
+
+	for _, s := range series {
+		ref := storage.SeriesRef(0)
+		it := s.Iterator()
+		lset := s.Labels()
+		for it.Next() {
+			t, v := it.At()
+			ref, err = app.Append(ref, lset, t, v)
+			if err != nil {
+				return "", err
+			}
+		}
+		if it.Err() != nil {
+			return "", it.Err()
+		}
+	}
+
+	if err = app.Commit(); err != nil {
 		return "", err
 	}
 
-	err = os.MkdirAll(dir, 0777)
-	if err != nil {
-		return "", err
-	}
-
-	ulid, err := compactor.Write(dir, head, mint, maxt, nil)
+	ulid, err := w.Flush(ctx)
 	if err != nil {
 		return "", err
 	}
